summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2013-05-31 22:08:14 +0100
committerCarl Hetherington <cth@carlh.net>2013-05-31 22:08:14 +0100
commitc8be8124ce89aee17df080745c9651d6e3975a4c (patch)
treea57482b1183a9c804d8cf6e2f4e734879af5994d /src
parent2adf3ce04f5bff645e40f7e8aca1c7e3c014375a (diff)
Various OS X tweaks.
Diffstat (limited to 'src')
-rw-r--r--src/tools/dvdomatic.cc27
-rw-r--r--src/wx/config_dialog.cc6
2 files changed, 20 insertions, 13 deletions
diff --git a/src/tools/dvdomatic.cc b/src/tools/dvdomatic.cc
index e6d4471db..9586e8d1e 100644
--- a/src/tools/dvdomatic.cc
+++ b/src/tools/dvdomatic.cc
@@ -148,13 +148,10 @@ enum {
ID_file_open,
ID_file_save,
ID_file_properties,
- ID_file_quit,
- ID_edit_preferences,
ID_jobs_make_dcp,
ID_jobs_send_dcp_to_tms,
ID_jobs_show_dcp,
ID_jobs_analyse_audio,
- ID_help_about
};
void
@@ -168,10 +165,14 @@ setup_menu (wxMenuBar* m)
file->AppendSeparator ();
add_item (file, _("&Properties..."), ID_file_properties, NEEDS_FILM);
file->AppendSeparator ();
- add_item (file, _("&Quit"), ID_file_quit, ALWAYS);
+ add_item (file, _("&Exit"), wxID_EXIT, ALWAYS);
+#ifdef __WXOSX__
+ add_item (file, _("&Preferences..."), wxID_PREFERENCES, ALWAYS);
+#else
wxMenu* edit = new wxMenu;
- add_item (edit, _("&Preferences..."), ID_edit_preferences, ALWAYS);
+ add_item (edit, _("&Preferences..."), wxID_PREFERENCES, ALWAYS);
+#endif
jobs_menu = new wxMenu;
add_item (jobs_menu, _("&Make DCP"), ID_jobs_make_dcp, NEEDS_FILM);
@@ -181,10 +182,16 @@ setup_menu (wxMenuBar* m)
add_item (jobs_menu, _("&Analyse audio"), ID_jobs_analyse_audio, NEEDS_FILM);
wxMenu* help = new wxMenu;
- add_item (help, _("About"), ID_help_about, ALWAYS);
+#ifdef __WXOSX__
+ add_item (help, _("About DVD-o-matic"), wxID_ABOUT, ALWAYS);
+#else
+ add_item (help, _("About"), wxID_ABOUT, ALWAYS);
+#endif
m->Append (file, _("&File"));
+#ifndef __WXOSX__
m->Append (edit, _("&Edit"));
+#endif
m->Append (jobs_menu, _("&Jobs"));
m->Append (help, _("&Help"));
}
@@ -210,13 +217,13 @@ public:
Connect (ID_file_open, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler (Frame::file_open));
Connect (ID_file_save, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler (Frame::file_save));
Connect (ID_file_properties, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler (Frame::file_properties));
- Connect (ID_file_quit, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler (Frame::file_quit));
- Connect (ID_edit_preferences, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler (Frame::edit_preferences));
+ Connect (wxID_EXIT, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler (Frame::file_exit));
+ Connect (wxID_PREFERENCES, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler (Frame::edit_preferences));
Connect (ID_jobs_make_dcp, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler (Frame::jobs_make_dcp));
Connect (ID_jobs_send_dcp_to_tms, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler (Frame::jobs_send_dcp_to_tms));
Connect (ID_jobs_show_dcp, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler (Frame::jobs_show_dcp));
Connect (ID_jobs_analyse_audio, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler (Frame::jobs_analyse_audio));
- Connect (ID_help_about, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler (Frame::help_about));
+ Connect (wxID_ABOUT, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler (Frame::help_about));
Connect (wxID_ANY, wxEVT_MENU_OPEN, wxMenuEventHandler (Frame::menu_opened));
@@ -367,7 +374,7 @@ private:
d->Destroy ();
}
- void file_quit (wxCommandEvent &)
+ void file_exit (wxCommandEvent &)
{
maybe_save_then_delete_film ();
Close (true);
diff --git a/src/wx/config_dialog.cc b/src/wx/config_dialog.cc
index 98657b666..4daf581ba 100644
--- a/src/wx/config_dialog.cc
+++ b/src/wx/config_dialog.cc
@@ -18,7 +18,7 @@
*/
/** @file src/config_dialog.cc
* @brief A dialogue to edit DCP-o-matic configuration.
*/
#include <iostream>
@@ -43,7 +43,7 @@ using namespace std;
using boost::bind;
ConfigDialog::ConfigDialog (wxWindow* parent)
- : wxDialog (parent, wxID_ANY, _("DCP-o-matic Preferences"), wxDefaultPosition, wxDefaultSize, wxDEFAULT_DIALOG_STYLE | wxRESIZE_BORDER)
+ : wxDialog (parent, wxID_ANY, _("DVD-o-matic Preferences"), wxDefaultPosition, wxDefaultSize, wxDEFAULT_DIALOG_STYLE | wxRESIZE_BORDER)
{
wxBoxSizer* s = new wxBoxSizer (wxVERTICAL);
_notebook = new wxNotebook (this, wxID_ANY);
@@ -95,7 +95,7 @@ ConfigDialog::make_misc_panel ()
table->Add (_language, 1, wxEXPAND);
table->AddSpacer (0);
- wxStaticText* restart = add_label_to_sizer (table, _misc_panel, _("(restart DCP-o-matic to see language changes)"));
+ wxStaticText* restart = add_label_to_sizer (table, _misc_panel, _("(restart DVD-o-matic to see language changes)"));
wxFont font = restart->GetFont();
font.SetStyle (wxFONTSTYLE_ITALIC);
font.SetPointSize (font.GetPointSize() - 1);
@@ -18,7 +18,7 @@
*/
/** @file src/config_dialog.cc
- * @brief A dialogue to edit DCP-o-matic configuration.
+ * @brief A dialogue to edit DVD-o-matic configuration.
*/
#include <iostream>